// ECMAScript 5 strict mode
"use strict";

assert2(cr, "cr namespace not created");
assert2(cr.plugins_, "cr.plugins_ not created");

cr.plugins_.VinoosAdivery = function(runtime)
{
	this.runtime = runtime;
};

(function ()
{	
	var pluginProto = cr.plugins_.VinoosAdivery.prototype;
		
/////////////////////////////////////
// Object type class
	pluginProto.Type = function(plugin)
	{
		this.plugin = plugin;
		this.runtime = plugin.runtime;
	};

	var typeProto = pluginProto.Type.prototype;

	var errorMessage = "";
	
// called on startup for each object type
	typeProto.onCreate = function()
	{
		if(this.runtime.isBlackberry10 || this.runtime.isWindows8App || this.runtime.isWindowsPhone8 || this.runtime.isWindowsPhone81){
			var scripts=document.getElementsByTagName("script");
			var scriptExist=false;
			for(var i=0;i<scripts.length;i++){
				if(scripts[i].src.indexOf("cordova.js")!=-1||scripts[i].src.indexOf("phonegap.js")!=-1){
					scriptExist=true;
					break;
				}
			}
			if(!scriptExist){
				var newScriptTag=document.createElement("script");
				newScriptTag.setAttribute("type","text/javascript");
				newScriptTag.setAttribute("src", "cordova.js");
				document.getElementsByTagName("head")[0].appendChild(newScriptTag);
			}
		}
	};

/////////////////////////////////////
// Instance class
	pluginProto.Instance = function(type)
	{
		this.type = type;
		this.runtime = type.runtime;
	};
	
	var instanceProto = pluginProto.Instance.prototype;
	
	var isSupported = false;
	
// called whenever an instance is created
	instanceProto.onCreate = function()
	{
		if (!window["Adivery"])
		{
			cr.logexport("[Construct 2] miladesign.cordova.AdiveryPlugin plugin is required to show Adivery ads with Cordova; other platforms are not supported");
			return;
		}
		
		isSupported = true;
		
		var self = this;
		
		var appId = this.properties[0];
		
		Adivery.initialize(appId);
	
		document.addEventListener('onAdLoaded',function(data){
			if(data.adType == 'Interstitial') {
				self.runtime.trigger(cr.plugins_.VinoosAdivery.prototype.cnds.onInterstitialAdLoaded, self);
			} else if(data.adType == 'Rewarded') {
				self.runtime.trigger(cr.plugins_.VinoosAdivery.prototype.cnds.onRewardedAdLoaded, self);
			}
		});
		
		document.addEventListener('onAdRewarded',function(data){
			self.runtime.trigger(cr.plugins_.VinoosAdivery.prototype.cnds.onAdRewarded, self);
		});
		
		document.addEventListener('onShowFailed',function(data){
			errorMessage = data.message;
			self.runtime.trigger(cr.plugins_.VinoosAdivery.prototype.cnds.onShowFailed, self);
		});

	};
	
	instanceProto.draw = function(ctx)
	{
	};
	instanceProto.drawGL = function (glw)
	{
	};

//////////////////////////////////////
// Conditions
	function Cnds() {};

	/*** - Banner Conditions - ***/
	Cnds.prototype.onInterstitialAdLoaded = function () {
		return true;
	};
	
	Cnds.prototype.onRewardedAdLoaded = function () {
		return true;
	};
	
	Cnds.prototype.onAdRewarded = function () {
		return true;
	};
	
	Cnds.prototype.onShowFailed = function () {
		return true;
	};
	
	pluginProto.cnds = new Cnds();
	
//////////////////////////////////////
// Actions
	function Acts() {};
	
	Acts.prototype.createBanner = function (zoneid, position, size) {
		if (!isSupported)
			return;
		
		Adivery.createBanner(zoneid, position, (size+1));
	};
	
	Acts.prototype.createBannerAtXY = function (zoneid, x, y, size) {
		if (!isSupported)
			return;
		
		Adivery.createBannerAtXY(zoneid, x, y, (size+1));
	};
	
	Acts.prototype.removeBanner = function () {
		if (!isSupported)
			return;
		
		Adivery.removeBanner();
	};
	
	Acts.prototype.showBanner = function () {
		if (!isSupported)
			return;
		
		Adivery.showBanner();
	};
	
	Acts.prototype.hideBanner = function () {
		if (!isSupported)
			return;
		
		Adivery.hideBanner();
	};
	
	Acts.prototype.requestInterstitialAd = function (zoneid) {
		if (!isSupported)
			return;
		
		Adivery.requestInterstitialAd(zoneid);
	};
	
	Acts.prototype.requestRewardedAd = function (zoneid) {
		if (!isSupported)
			return;
		
		Adivery.requestRewardedAd(zoneid);
	};
	
	Acts.prototype.showAd = function () {
		if (!isSupported)
			return;
		
		Adivery.showAd();
	};
	
	pluginProto.acts = new Acts();
	
//////////////////////////////////////
// Expressions
	function Exps() {};

	Exps.prototype.ErrorMessage = function (ret) {
		ret.set_string(errorMessage);
	};

	pluginProto.exps = new Exps();

}());